import { AbstractDynamicSnippetsGeneratorContext, FernGeneratorExec, Options } from '@fern-api/browser-compatible-base-generator';
import { FernIr } from '@fern-api/dynamic-ir-sdk';
import { java, BaseJavaCustomConfigSchema } from '@fern-api/java-ast';

declare namespace DynamicTypeLiteralMapper {
    interface Args {
        typeReference: FernIr.dynamic.TypeReference;
        value: unknown;
        as?: ConvertedAs;
    }
    type ConvertedAs = "mapKey" | "mapValue";
}
declare class DynamicTypeLiteralMapper {
    private context;
    constructor({ context }: {
        context: DynamicSnippetsGeneratorContext;
    });
    convert(args: DynamicTypeLiteralMapper.Args): java.TypeLiteral;
    private convertList;
    private convertLiteral;
    private convertSet;
    private convertMap;
    private convertNamed;
    private convertDiscriminatedUnion;
    private convertObject;
    private convertEnum;
    private getEnumValueName;
    private convertUndiscriminatedUnion;
    private findMatchingUndiscriminatedUnionType;
    private getUndiscriminatedUnionFieldName;
    private getUndiscriminatedUnionFieldNameForList;
    private getUndiscriminatedUnionFieldNameForMap;
    private getUndiscriminatedUnionFieldNameForOptional;
    private getUndiscriminatedUnionFieldNameForNullable;
    private getUndiscriminatedUnionFieldNameForSet;
    private getUndiscriminatedUnionFieldNameForLiteral;
    private getUndiscriminatedUnionFieldNameForPrimitive;
    private convertUnknown;
    private convertPrimitive;
    private getValueAsNumber;
    private getValueAsBoolean;
}

declare namespace DynamicTypeMapper {
    interface Args {
        typeReference: FernIr.dynamic.TypeReference;
    }
}
declare class DynamicTypeMapper {
    private context;
    constructor({ context }: {
        context: DynamicSnippetsGeneratorContext;
    });
    convert(args: DynamicTypeMapper.Args): java.Type;
    private convertNamed;
    private convertLiteral;
    private convertUnknown;
    private convertPrimitive;
}

interface FilePropertyInfo {
    fileFields: java.BuilderParameter[];
    bodyPropertyFields: java.BuilderParameter[];
}
declare class FilePropertyMapper {
    private context;
    constructor({ context }: {
        context: DynamicSnippetsGeneratorContext;
    });
    getFilePropertyInfo({ body, value }: {
        body: FernIr.dynamic.FileUploadRequestBody;
        value: unknown;
    }): FilePropertyInfo;
    private getSingleFileProperty;
    private getArrayFileProperty;
    private getBodyProperty;
}

declare class DynamicSnippetsGeneratorContext extends AbstractDynamicSnippetsGeneratorContext {
    ir: FernIr.dynamic.DynamicIntermediateRepresentation;
    customConfig: BaseJavaCustomConfigSchema | undefined;
    dynamicTypeMapper: DynamicTypeMapper;
    dynamicTypeLiteralMapper: DynamicTypeLiteralMapper;
    filePropertyMapper: FilePropertyMapper;
    constructor({ ir, config, options }: {
        ir: FernIr.dynamic.DynamicIntermediateRepresentation;
        config: FernGeneratorExec.GeneratorConfig;
        options?: Options;
    });
    clone(): DynamicSnippetsGeneratorContext;
    getClassName(name: FernIr.Name): string;
    getEnumName(name: FernIr.Name): string;
    getPropertyName(name: FernIr.Name): string;
    getMethodName(name: FernIr.Name): string;
    getRootClientClassReference(): java.ClassReference;
    getRootClientClassName(): string;
    getEnvironmentClassName(): string;
    getEnvironmentTypeReferenceFromID(environmentID: string): java.AstNode | undefined;
    getEnvironmentClassReference(): java.ClassReference;
    getJavaClassReferenceFromDeclaration({ declaration }: {
        declaration: FernIr.dynamic.Declaration;
    }): java.ClassReference;
    getNullableClassReference(): java.ClassReference;
    getNullableOfNull(): java.TypeLiteral;
    getFileStreamFromString(content: string): java.TypeLiteral;
    getFileStreamClassReference(): java.ClassReference;
    getByteArrayInputStreamClassReference(): java.ClassReference;
    getStandardCharsetsClassReference(): java.ClassReference;
    isPrimitive(typeReference: FernIr.dynamic.TypeReference): boolean;
    getRootPackageName(): string;
    getCorePackageName(): string;
    getTypesPackageName(fernFilepath: FernIr.FernFilepath): string;
    getRequestsPackageName(fernFilepath: FernIr.FernFilepath): string;
    protected getResourcesPackage(fernFilepath: FernIr.FernFilepath, suffix?: string): string;
    getPackageName(fernFilepath: FernIr.FernFilepath, suffix?: string): string;
    getPackageLayout(): string;
    shouldInlinePathParameters(): boolean;
    shouldInlineFileProperties(): boolean;
    private getPackageNameSegments;
    private getPackageNameSegment;
    private getPackagePrefixTokens;
    private getBaseNamePrefix;
    private getApiName;
    private startsWithNumber;
    private splitOnNonAlphaNumericChar;
    private convertKebabCaseToUpperCamelCase;
    private joinPackageTokens;
    private getName;
    private isReservedName;
}

export { DynamicSnippetsGeneratorContext as D, type FilePropertyInfo as F, DynamicTypeLiteralMapper as a, DynamicTypeMapper as b, FilePropertyMapper as c };
